yandex-conqueror
================

List of [contributors](CONTRIBUTORS.md) available in a separate file.

How to use it?
==============

At first, create a Yandex account. Make sure that you're able to log-in, ie. activate all mail and SMS passwords.

Then install Python 3.10, necessarily adding Python to PATH.

Then enter command line and type:

```bash
pip install yandex-conqueror
python -m conqueror <yandex email> <yandex password>
```

If you wish for the interactive window not to appear, you can always substitute the second command
with

```bash
python -m conqueror <yandex email> <yandex password> --headless
```
